@@ -3,22 +3,27 @@ Failing versions of all of the check helper functions.
 """
 from pytest_check import check
 
+
 def test_equal():
-    check.equal(1,2)
+    check.equal(1, 2)
+
 
 def test_not_equal():
-    check.not_equal(1,1)
+    check.not_equal(1, 1)
+
 
 def test_is():
     x = ["foo"]
     y = ["foo"]
     check.is_(x, y)
 
+
 def test_is_not():
     x = ["foo"]
     y = x
     check.is_not(x, y)
 
+
 def test_is_true():
     check.is_true(False)
 
@@ -52,6 +57,7 @@ def test_is_instance():
 def test_is_not_instance():
     check.is_not_instance(1, int)
 
+
 def test_almost_equal():
     check.almost_equal(1, 2)
     check.almost_equal(1, 2.1, abs=0.1)
@@ -79,4 +85,20 @@ def test_less():
 
 
 def test_less_equal():
-    check.less_equal(2, 1)
\ No newline at end of file
+    check.less_equal(2, 1)
+
+
+def test_between():
+    check.between(0, 0, 20)
+
+
+def test_between_ge():
+    check.between(20, 0, 20, ge=True)
+
+
+def test_between_le():
+    check.between(0, 0, 20, le=True)
+
+
+def test_between_ge_le():
+    check.between(21, 0, 20, ge=True, le=True)
